@@ -431,6 +431,8 @@ skip_impl = {
     'virDomainAuthorizedSSHKeysSet',
     'virDomainGetMessages',
     'virNodeDeviceGetAutostart',
+    'virDomainSaveParams',
+    'virDomainRestoreParams',
 
     'virDomainLxcOpenNamespace',
 
@@ -482,6 +484,7 @@ skip_function = {
     'virConnectListAllSecrets',  # overridden in virConnect.py
     'virConnectGetAllDomainStats',  # overridden in virConnect.py
     'virDomainListGetStats',  # overridden in virConnect.py
+    'virDomainFDAssociate',  # overridden in virDomain.py
 
     'virStreamRecvAll',  # Pure python libvirt-override-virStream.py
     'virStreamSendAll',  # Pure python libvirt-override-virStream.py
@@ -878,6 +881,7 @@ def emit_c_code(module: str) -> None:
 
     wrapper = open(wrapper_file, "w")
     wrapper.write("/* Generated by generator.py */\n\n")
+    wrapper.write("#include <stdlib.h>\n")
     wrapper.write("#include <Python.h>\n")
     wrapper.write("#include <libvirt/%s.h>\n" % (module,))
     wrapper.write("#include \"typewrappers.h\"\n")
